# Parade

[![Build Status](https://travis-ci.org/bailaohe/parade.svg?branch=master)](https://travis-ci.org/bailaohe/parade)

`Parade` is a simple and out-of-box toolkit to handle data work such as ETL, data analysis, BI reports, etc, and enable fast and flexible integration mechanism with applications. It can be used for a wide range of purposes, from composing & scheduling data workflow to providing unified web-APIs of data query.

## Requirements

* Python 3.4+
* Works on Linux, Windows, Mac OSX, BSD

## Install

The quich way:

```bash
> pip install parade
```

## Basic Usage & Tutorials

See [here](http://parade.readthedocs.io/en/latest/).
